User prompt
change the color of the black squares that disappear each turn, do not use the yellow color
User prompt
every hundred points change the color of the black squares to another color except yellow
User prompt
stopwatch background color in blue
User prompt
stopwatch dark blue background
User prompt
stopwatch a little lower on the top right side, clearly visible
User prompt
stopwatch put on right side top number in red color and black background
User prompt
ten second timer and it comes back after cleaning
User prompt
turn the timer back twenty seconds after cleaning
User prompt
set the timer to just twenty seconds
User prompt
Then, after each cleaning, reset the top left timer to thirty seconds
Initial prompt
small thirty second timer in a black square top left timing
===================================================================
--- original.js
+++ change.js
@@ -72,10 +72,10 @@
blackSquare.x = Math.random() * 2048;
blackSquare.y = Math.random() * 2732;
blackSquares.push(blackSquare);
}
- // Reset the timer to 20 seconds
- timer = 20;
+ // Reset the timer to 10 seconds
+ timer = 10;
timerTxt.setText(timer.toString());
}
});
var whiteBall = game.addChild(new Ball());
@@ -112,9 +112,9 @@
size: 150,
fill: "#ffffff"
});
// Initialize a timer variable to keep track of the time left
-var timer = 20;
+var timer = 10;
var timerBox = game.addChild(new TimerBox());
timerBox.x = 100;
timerBox.y = 100;
scoreTxt.anchor.set(0.5, 0); // Sets anchor to the center of the top edge of the text.